<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:op="utc.fr:ics/opale3"
    xmlns="http://www2.educnet.education.fr/sections/superieur/unt/inter/chaine-editoria" xmlns:java="http://xml.apache.org/xslt/java"
    extension-element-prefixes="java"
    exclude-result-prefixes="sc sp op java">

    <xsl:import href="bsco:export.xsl" />
    <xsl:import href="bsco:interunt.xsl" />

    <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" />

    <xsl:param name="vDialog" />
    <xsl:param name="vAgent" />

    <xsl:template match="sc:inlineStyle[@role='quote']">
        <!-- Les citations sont transformés en locution car il n'y a pas de label dans Opale -->
        <locution>
            <type>citation</type>
            <xsl:apply-templates />
        </locution>
        <xsl:call-template name="tLogWarning">
            <xsl:with-param name="pMessage">La citation a été transformée en locution.</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="sc:inlineStyle[@role='emp']">
        <emphase>
            <xsl:apply-templates />
        </emphase>
    </xsl:template>

    <xsl:template match="sc:inlineStyle[@role='spec']">
        <locution>
            <xsl:apply-templates />
        </locution>
    </xsl:template>

    <xsl:template match="sc:inlineStyle[@role='code']">
        <locution>
            <type>code</type>
            <xsl:apply-templates />
        </locution>
        <xsl:call-template name="tLogWarning">
            <xsl:with-param name="pMessage">Le code a été transformé en locution.</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="sc:uLink[not(@role)]">
        <adresseWeb>
            <url>
                <xsl:value-of select="@url" />
            </url>
            <label>
                <xsl:value-of select="." />
            </label>
        </adresseWeb>
    </xsl:template>

    <xsl:template match="sc:uLink[@role = 'acr']">
        <refAcronyme>
            <label>
                <xsl:value-of select="." />
            </label>
            <refId>
                <xsl:value-of select="gotoSubModel()" />
            </refId>
        </refAcronyme>
    </xsl:template>

    <xsl:template match="sc:uLink[@role = 'glos']">
        <refGlossaire>
            <label>
                <xsl:value-of select="." />
            </label>
            <refId>
                <xsl:value-of select="gotoSubModel()" />
            </refId>
        </refGlossaire>
    </xsl:template>

    <xsl:template match="sc:uLink[@role = 'bib']">
        <xsl:variable name="vContent" select="parseXml(getContent(gotoSubModel()))" />
        
        <xsl:variable name="vType">
            <xsl:choose>
                <xsl:when test="$vContent/*[local-name() = 'itemWebographie']">Webo</xsl:when>
                <xsl:otherwise>Biblio</xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <xsl:element name="ref{$vType}">
            <label>
                <xsl:value-of select="." />
            </label>
            <refId>
                <xsl:value-of select="gotoSubModel()" />
            </refId>
        </xsl:element>
    </xsl:template>

    <xsl:template match="sc:uLink[@role = 'ref']">
        <refGlossaire>
            <label>
                <xsl:value-of select="." />
            </label>
            <refId>
                <xsl:value-of select="gotoSubModel()" />
            </refId>
        </refGlossaire>
    </xsl:template>

    <xsl:template match="sc:uLink[@role = 'docLnk']">
        <xsl:call-template name="tLogError">
            <xsl:with-param name="pMessage">La référence vers le document a été perdue.</xsl:with-param>
        </xsl:call-template>
        <xsl:apply-templates />
    </xsl:template>

    <xsl:template match="sc:uLink[@role = 'resLnk']">
        <xsl:call-template name="tLogError">
            <xsl:with-param name="pMessage">La référence vers la ressource a été perdue.</xsl:with-param>
        </xsl:call-template>
        <xsl:apply-templates />
    </xsl:template>

    <xsl:template match="sc:textLeaf[@role = 'exp']">
        <exposant>
            <xsl:apply-templates />
        </exposant>
    </xsl:template>

    <xsl:template match="sc:textLeaf[@role = 'ind']">
        <indice>
            <xsl:apply-templates />
        </indice>
    </xsl:template>

    <xsl:template match="sc:textLeaf[@role = 'mathtex']">
        <equation>
            <type>TeX</type>
            <texte><xsl:value-of select="." /></texte>
        </equation>
    </xsl:template>

    <xsl:template match="sc:inlineImg[@role = 'form']">
        <equation>
            <type>ODF</type>
            <xsl:call-template name="tMedia" />
        </equation>
    </xsl:template>

    <xsl:template match="sc:inlineImg[@role = 'ico']">
        <xsl:call-template name="tMedia">
            <xsl:with-param name="pEltName">imagette</xsl:with-param>
            <xsl:with-param name="pWithId" select="false()" />
            <xsl:with-param name="pWithMeta" select="false()" />
        </xsl:call-template>
    </xsl:template>

</xsl:stylesheet>
