<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:op="utc.fr:ics/opale3"
	xmlns="http://www2.educnet.education.fr/sections/superieur/unt/inter/chaine-editoria"
	xmlns:java="http://xml.apache.org/xslt/java" extension-element-prefixes="java"
	exclude-result-prefixes="sc sp op">

	<xsl:import href="bsco:export.xsl" />

	<!-- Retourne un identifiant unique -->
	<xsl:template name="tId">
		<xsl:param name="pNum" select="0" />

		<xsl:value-of select="currentModel()" />
		<xsl:text>_</xsl:text>
		<xsl:value-of select="generate-id()" />
		<xsl:text>_</xsl:text>
		<xsl:value-of select="$pNum" />
	</xsl:template>

	<!-- Crée l'élément id -->
	<xsl:template name="tIdElt">
		<xsl:param name="pNum" select="0" />
		<id>
			<xsl:call-template name="tId">
				<xsl:with-param name="pNum" select="$pNum" />
			</xsl:call-template>
		</id>
	</xsl:template>

	<!-- Crée l'élément niveau -->
	<xsl:template name="tLevelElt">
		<niveau>
			<xsl:choose>
				<xsl:when test="string-length(getDialogVar('level'))">
					<xsl:value-of select="getDialogVar('level')" />
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</niveau>
	</xsl:template>

	<!-- Crée l'élément niveau -->
	<xsl:template name="tIncrementLevel">
		<xsl:variable name="setDialogVar" select="setDialogVar('level', getDialogVar('level') + 1)" />
	</xsl:template>

	<!-- Retourne l'URI d'un item référencé ou de l'item courant par défaut sous l'axis 'page' -->
	<xsl:template name="tRefUri">
		<xsl:param name="pCurrentModel" select="false()" />
		<xsl:param name="pAxis">page</xsl:param>

		<xsl:variable name="vPath"
			select="getContent(si($pCurrentModel,currentModel(), gotoSubModel()), $pAxis)" />


		<!-- On coupe la chaîne pour arriver à une URI absolu par rapport à l'atelier -->
		<xsl:variable name="vAbsPath"
			select="concat('/', substring-after(substring-after(substring-after(substring-after($vPath, '/'), '/'), '/'), '/'))" />

		<!-- On coupe la chaîne pour arriver à une URI absolu par rapport à l'atelier -->
		<xsl:variable name="vCurrentAbsPath"
			select="concat('/', substring-after(substring-after(java:hGetUri(srcFileAgent('//')), '/'), '/'))" />

		<xsl:value-of
			select="java:com.scenari.m.ge.generateur.GeneratorBase.buildRelativeUrl($vCurrentAbsPath, $vAbsPath)"
		 />
	</xsl:template>

	<!-- Crée l'attribut refUri en utilisant tRefUri -->
	<xsl:template name="tRefUriElt">
		<xsl:param name="pCurrentModel" select="false()" />
		<xsl:param name="pAxis">page</xsl:param>

		<refDocInterUnt>
			<fichier>
				<xsl:call-template name="tRefUri">
					<xsl:with-param name="pAxis" select="$pAxis" />
					<xsl:with-param name="pCurrentModel" select="$pCurrentModel" />
				</xsl:call-template>
			</fichier>
		</refDocInterUnt>
	</xsl:template>

	<!-- Patron utilitaire pour signaler l'inexistance d'un élément dans inter-UNT -->
	<xsl:template name="tNoMatch">
		<xsl:call-template name="tLogError">
			<xsl:with-param name="pMessage">
				<xsl:text>'</xsl:text>
				<xsl:apply-templates select="." mode="label" />
				<xsl:text>' n'a pas de correspondance dans inter-UNT.</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<!-- Patron de debug pour afficher dans le log les éléments non capturés -->
	<xsl:template match="*">
		<xsl:call-template name="tLogDebug">
			<xsl:with-param name="pMessage">L'élément '<xsl:value-of select="name(.)" />' n'a pas
				été capturé.</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<!-- Extraction de l'extension d'un nom de fichier -->
	<xsl:template name="tExtension">
		<xsl:param name="pFilename" />

		<!-- Appel récursif du patron tant que l'extension contient un point -->
		<xsl:variable name="vExtension" select="substring-after($pFilename, '.')" />
		<xsl:choose>
			<xsl:when test="contains($vExtension,'.')">
				<xsl:call-template name="tExtension">
					<xsl:with-param name="pFilename" select="$vExtension" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$vExtension" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="tMedia">
		<xsl:param name="pEltName">media</xsl:param>
		<xsl:param name="pWithId" select="true()" />
		<xsl:param name="pWithMeta" select="true()" />

		<xsl:variable name="vExtension">
			<xsl:call-template name="tExtension">
				<xsl:with-param name="pFilename" select="extractFileNameFromPath(@sc:refUri)" />
			</xsl:call-template>
		</xsl:variable>

		<!-- TODO -->
		<xsl:element name="{$pEltName}">
			<xsl:if test="$pWithId">
				<xsl:call-template name="tIdElt" />
			</xsl:if>
			<typeMIME>
				<xsl:choose>
					<xsl:when test="$vExtension = 'avi'">video/x-msvideo</xsl:when>
					<xsl:when test="$vExtension = 'doc'">application/msword</xsl:when>
					<xsl:when test="$vExtension = 'swf'">application/x-shockwave-flash</xsl:when>
					<xsl:when test="$vExtension = 'flv'">video/x-flv</xsl:when>
					<xsl:when test="$vExtension = 'gif'">image/gif</xsl:when>
					<xsl:when test="$vExtension = 'jpg' or $vExtension = 'jpeg'">image/jpeg</xsl:when>
					<xsl:when test="$vExtension = 'mov'">video/quicktime</xsl:when>
					<xsl:when test="$vExtension = 'mp3'">audio/mpeg</xsl:when>
					<xsl:when test="$vExtension = 'mpg' or $vExtension = 'mpeg'">video/mpeg</xsl:when>
					<xsl:when test="$vExtension = 'odg'">application/vnd.oasis.opendocument.graphics</xsl:when>
					<xsl:when test="$vExtension = 'odp'"
						>application/vnd.oasis.opendocument.presentation</xsl:when>
					<xsl:when test="$vExtension = 'ods'"
						>application/vnd.oasis.opendocument.spreadsheet</xsl:when>
					<xsl:when test="$vExtension = 'odt'">application/vnd.oasis.opendocument.text</xsl:when>
					<xsl:when test="$vExtension = 'pdf'">application/pdf</xsl:when>
					<xsl:when test="$vExtension = 'png'">image/png</xsl:when>
					<xsl:when test="$vExtension = 'ppt' or $vExtension = 'pps'"
						>application/vnd.ms-powerpoint</xsl:when>
					<xsl:when test="$vExtension = 'rm'">video/x-pn-realaudio</xsl:when>
					<xsl:when test="$vExtension = 'wmv'">video/x-ms-wmv</xsl:when>
					<xsl:when test="$vExtension = 'xls'">application/vnd.ms-excel</xsl:when>
					<xsl:when test="$vExtension = 'zip'">application/zip</xsl:when>

					<xsl:when test="$vExtension = 'odf'">application/vnd.oasis.opendocument.formula</xsl:when>
					<xsl:when test="$vExtension = 'mml'">application/mathml+xml</xsl:when>
					<xsl:when test="$vExtension = 'mtex'">application/x-tex</xsl:when>
				</xsl:choose>
			</typeMIME>
			<fichier>
				<xsl:call-template name="tRefUri" />
			</fichier>
			<xsl:if test="$pWithMeta">
				<xsl:value-of select="getContent(gotoMeta(gotoSubModel()))"
					disable-output-escaping="yes" />
			</xsl:if>
			<xsl:value-of select="getContent(gotoSubModel(),'dim')" disable-output-escaping="yes" />
		</xsl:element>
	</xsl:template>

	<!-- Patron utilitaire pour signaler qu'un format n'est pas supporté (utilisé dans Re.xsl) -->
	<xsl:template name="tNotSupportedFormat">
		<xsl:param name="pFormat" />

		<xsl:call-template name="tLogError">
			<xsl:with-param name="pMessage">
				<xsl:text>Les fichiers '</xsl:text>
				<xsl:value-of select="$vFormat" />
				<xsl:text>' des '</xsl:text>
				<xsl:apply-templates select="$pBinaryElement" mode="label" />
				<xsl:text>' ne sont pas supportés par inter-UNT.</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<!-- Patron utilitaire pour générer le titre d'un quiz -->
	<xsl:template name="tQuizTitle">
		<title>
			<fullTitle>
				<xsl:apply-templates select="." mode="label" />
			</fullTitle>
		</title>
		<xsl:call-template name="tLogInfo">
			<xsl:with-param name="pMessage">
				<xsl:text>Le titre du quiz a été défini à '</xsl:text>
				<xsl:apply-templates select="." mode="label" />
				<xsl:text>'.</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<!-- Patrons utilitaire pour générer la bibliograhpie -->
	<xsl:template name="tRefs">
		<bibliographie>
			<xsl:apply-templates mode="biblio" />
		</bibliographie>
		<glossaire>
			<xsl:apply-templates mode="gloss" />
		</glossaire>
		<acronymes>
			<xsl:apply-templates mode="acr" />
		</acronymes>
	</xsl:template>

	<xsl:template match="sp:genRef" />

	<xsl:template match="op:ue | op:ueDiv | op:courseUa | op:expUc" mode="biblio" />

	<xsl:template match="node()" mode="biblio">
		<xsl:apply-templates mode="biblio" />
	</xsl:template>

	<xsl:template match="sc:uLink[@role = 'bib']" mode="biblio">
		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
	</xsl:template>

	<xsl:template match="op:genRef/sp:ref" mode="biblio">
		<xsl:variable name="vType" select="typeAgent(concat('@',gotoSubModel()))" />
		<xsl:if test="$vType = 'op_bib'">
			<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
		</xsl:if>
	</xsl:template>


	<xsl:template match="op:ue | op:ueDiv | op:courseUa | op:expUc | op:expUc" mode="gloss" />

	<xsl:template match="node()" mode="gloss">
		<xsl:apply-templates mode="gloss" />
	</xsl:template>

	<xsl:template match="sc:uLink[@role = 'glos'] | sc:uLink[@role = 'ref']" mode="gloss">
		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
	</xsl:template>

	<xsl:template match="op:genRef/sp:ref" mode="gloss">
		<xsl:variable name="vType" select="typeAgent(concat('@',gotoSubModel()))" />
		<xsl:if test="$vType = 'op_glos' or $vType = 'op_ref'">
			<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
		</xsl:if>
	</xsl:template>


	<xsl:template match="op:ue | op:ueDiv | op:courseUa | op:expUc | op:expUc" mode="acr" />

	<xsl:template match="node()" mode="acr">
		<xsl:apply-templates mode="acr" />
	</xsl:template>

	<xsl:template match="sc:uLink[@role = 'acr']" mode="acr">
		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
	</xsl:template>

	<xsl:template match="op:genRef/sp:ref" mode="acr">
		<xsl:variable name="vType" select="typeAgent(concat('@',gotoSubModel()))" />
		<xsl:if test="$vType = 'op_acr'">
			<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>
