<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:op="utc.fr:ics/opale3"
	xmlns:lom="http://ltsc.ieee.org/xsd/LOM" xmlns:lomfr="http://www.lom-fr.fr/xsd/LOMFR"
	exclude-result-prefixes="sc sp op">

	<xsl:import href="bsco:export.xsl" />
	<xsl:import href="bsco:interunt.xsl" />

	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" />

	<xsl:param name="vDialog" />
	<xsl:param name="vAgent" />

	<xsl:variable name="vLanguage">
		<xsl:choose>
			<xsl:when test="sp:dc/op:dc/sp:lang = 'FR'">fr</xsl:when>
			<xsl:when test="sp:dc/op:dc/sp:lang = 'EN'">en</xsl:when>
			<xsl:when test="sp:dc/op:dc/sp:lang = 'OT'">en</xsl:when>
			<xsl:otherwise>fr</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:template match="op:info">
		<lom:lom>
			<lom:general>
				<lom:identifier>
					<lom:catalog>unisciel</lom:catalog>
					<lom:entry>
						<xsl:call-template name="tId" />
					</lom:entry>
				</lom:identifier>
				<xsl:apply-templates select="../../sp:title" />
				<xsl:apply-templates select="sp:dc/op:dc/sp:lang" />
				<xsl:apply-templates select="sp:dc/op:dc/sp:desc" />
				<xsl:apply-templates select="sp:keywds/op:keywds/sp:keywd" />
				<xsl:apply-templates select="sp:dc/op:dc/sp:cover/sp:spatial" />

				<lom:structure>
					<lom:source>LOMv1.0</lom:source>
					<lom:value>hierarchical</lom:value>
				</lom:structure>
				<lom:aggregationLevel>
					<lom:source>LOMv1.0</lom:source>
					<lom:value>
						<xsl:choose>
							<xsl:when test="ancestor::op:ue">4</xsl:when>
							<xsl:when test="ancestor::op:courseUa | ancestor::op:assmntUa">3</xsl:when>
							<xsl:when
								test="ancestor::op:expUc | ancestor::op:practUc | ancestor::op:trainUc"
								>2</xsl:when>
							<xsl:otherwise>1</xsl:otherwise>
						</xsl:choose>
					</lom:value>
				</lom:aggregationLevel>
				<lomfr:documentType>
					<lomfr:source>LOMFRv1.0</lomfr:source>
					<lomfr:value>collection</lomfr:value>
				</lomfr:documentType>
			</lom:general>

			<lom:lifeCycle>
				<xsl:apply-templates
					select="sp:dc/op:dc/sp:auth | sp:dc/op:dc/sp:cont | sp:dc/op:dc/sp:publisher" />
			</lom:lifeCycle>

			<lom:metaMetadata>
				<lom:metadataSchema>LOM v.1.0</lom:metadataSchema>
				<lom:metadataSchema>LOMFR v.1.0</lom:metadataSchema>
			</lom:metaMetadata>

			<lom:educational>
				<xsl:apply-templates select="sp:dc/op:dc/sp:level" />
			</lom:educational>

			<lom:rights>
				<lom:copyrightAndOtherRestrictions>
					<lom:source>LOMv1.0</lom:source>
					<lom:value>
						<xsl:choose>
							<xsl:when test="sp:cc = 'publicdomain'">no</xsl:when>
							<xsl:otherwise>yes</xsl:otherwise>
						</xsl:choose>
					</lom:value>
				</lom:copyrightAndOtherRestrictions>
				<xsl:apply-templates select="sp:cc" />
			</lom:rights>
		</lom:lom>
	</xsl:template>

	<xsl:template name="tString">
		<xsl:param name="pValue" />
		<lom:string language="{$vLanguage}">
			<xsl:value-of select="$pValue" />
		</lom:string>
	</xsl:template>

	<xsl:template match="sp:title">
		<lom:title>
			<xsl:call-template name="tString">
				<xsl:with-param name="pValue" select="." />
			</xsl:call-template>
		</lom:title>
	</xsl:template>

	<xsl:template match="op:dc/sp:lang">
		<lom:language>
			<xsl:value-of select="$vLanguage" />
		</lom:language>
	</xsl:template>

	<xsl:template match="op:dc/sp:desc">
		<xsl:call-template name="tLogWarning">
			<xsl:with-param name="pMessage">La description a été mise à plat.</xsl:with-param>
		</xsl:call-template>

		<lom:description>
			<xsl:call-template name="tString">
				<xsl:with-param name="pValue" select="normalize-space(.)" />
			</xsl:call-template>
		</lom:description>
	</xsl:template>

	<xsl:template match="sp:keywd">
		<lom:keyword>
			<xsl:call-template name="tString">
				<xsl:with-param name="pValue" select="." />
			</xsl:call-template>
		</lom:keyword>
	</xsl:template>

	<xsl:template match="op:dc/sp:cover/sp:spatial">
		<lom:coverage>
			<lom:string language="fr">
				<xsl:choose>
					<xsl:when test=". = 'FR'">France</xsl:when>
					<xsl:when test=". = 'EN'">Grande-Bretagne</xsl:when>
				</xsl:choose>
			</lom:string>
		</lom:coverage>
	</xsl:template>

	<xsl:template match="op:dc/sp:cover/sp:spatial[. = 'OT']">
		<xsl:call-template name="tLogError">
			<xsl:with-param name="pMessage">La couverture spatiale définie à 'Autre' a été
			perdu.</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="op:dc/sp:auth | op:dc/sp:cont | op:dc/sp:publisher">
		<lom:contribute>
			<lom:role>
				<lom:source>LOMv1.0</lom:source>
				<lom:value>
					<xsl:apply-templates select="." mode="role" />
				</lom:value>
			</lom:role>
			<lom:entity>
				<xsl:text><![CDATA[BEGIN:VCARD
VERSION:3.0
N:]]></xsl:text>
				<xsl:value-of select="." />
				<xsl:text><![CDATA[
FN:]]></xsl:text>
				<xsl:value-of select="." />
				<xsl:text><![CDATA[
END:VCARD]]></xsl:text>
			</lom:entity>
			<xsl:apply-templates select="../sp:date" />
		</lom:contribute>
	</xsl:template>

	<xsl:template match="op:dc/sp:auth" mode="role">author</xsl:template>
	<xsl:template match="op:dc/sp:cont" mode="role">unknown</xsl:template>
	<xsl:template match="op:dc/sp:publisher" mode="role">publisher</xsl:template>

	<xsl:template match="sp:date">
		<lom:date>
			<lom:description>
				<xsl:call-template name="tString">
					<xsl:with-param name="pValue" select="." />
				</xsl:call-template>
			</lom:description>
		</lom:date>
	</xsl:template>

	<xsl:template match="sp:level">
		<lom:context>
			<lom:source>LOMv1.0</lom:source>
			<lom:value>higher education</lom:value>
		</lom:context>
		<lom:context>
			<lom:source>LOMFRv1.0</lom:source>
			<lom:value>
				<xsl:choose>
					<xsl:when test=". = 'L'">licence</xsl:when>
					<xsl:when test=". = 'M'">master</xsl:when>
					<xsl:when test=". = 'D'">doctorat</xsl:when>
				</xsl:choose>
			</lom:value>
		</lom:context>
	</xsl:template>

	<xsl:template match="sp:cc">
		<lom:description>
			<lom:string language="fr">
				<xsl:choose>
					<xsl:when test=". = 'publicdomain'">
						<xsl:text>Domaine public</xsl:text>
					</xsl:when>
					<xsl:when test=". = 'by'">
						<xsl:text>Creative Commons Paternité</xsl:text>
					</xsl:when>
					<xsl:when test=". = 'by-nc'">
						<xsl:text>Creative Commons Paternité, Pas d'Utilisation	Commerciale</xsl:text>
					</xsl:when>
					<xsl:when test=". = 'by-nc-nd'">
						<xsl:text>Creative Commons Paternité, Pas d'Utilisation Commerciale, Pas de Modification</xsl:text>
					</xsl:when>
					<xsl:when test=". = 'by-nc-sa'">
						<xsl:text>Creative Commons Paternité, Pas d'Utilisation Commerciale, Partage des Conditions Initiales à l'Identique</xsl:text>
					</xsl:when>
					<xsl:when test=". = 'by-nd'">
						<xsl:text>Creative Commons Paternité, Pas de Modification</xsl:text>
					</xsl:when>
					<xsl:when test=". = 'by-sa'">
						<xsl:text>Creative Commons Paternité, Partage des Conditions Initiales à l'Identique</xsl:text>
					</xsl:when>
				</xsl:choose>
			</lom:string>
		</lom:description>
	</xsl:template>
</xsl:stylesheet>


