<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
    xmlns="http://www.w3.org/1999/xhtml">
    
    <xsl:output doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
        doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" indent="yes" method="xml"
        encoding="UTF-8" />
    
    <xsl:key name="group-by-item" match="*[local-name()='message']" use="@item" />
    
    <xsl:param name="pDebug" select="false()" />
    
    <!-- XSL de conversion du log XML en log HTML -->
    <xsl:template match="/">
        <html>
            <head>
                <title>Journal de l'export</title>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
                <style>
                <![CDATA[
                    body {
                        font-size: 10pt;
                    }
                    
                    .fatal {
                        color: red;
                        font-weight: bold;
                    }
                    .error {
                        font-weight: bold;
                    }
                    .warning {
                        color: black;
                    }
                    .info {
                        color: black;
                    }
                    .debug {
                        color: lightgrey;
                    }
                    
                    .messagesList ul {
                        margin-top: 0;
                    }
                ]]>
                </style>
            </head>
            <body>
                <xsl:apply-templates />
            </body>
        </html>
    </xsl:template>
    
    <xsl:template match="*[local-name()='log']">
        <h1>Journal de l'export</h1>
        <div class="log">
            <!-- Affichage des messages "fatal" en premier -->
            <xsl:variable name="vFatal" select="*[@level='fatal' and not(preceding-sibling::* = .)]" />
            <xsl:if test="$vFatal">
                <ul>
                    <xsl:apply-templates select="$vFatal" mode="message" />
                </ul>
            </xsl:if>
            
            <!-- Les messages sont groupés par item -->
            <xsl:apply-templates select="*[not(@level='fatal')][generate-id(.)=generate-id(key('group-by-item', @item)[1])]" />
        </div>
    </xsl:template>

    <xsl:template match="*[local-name()='message']">
        <xsl:if test="not(@level = 'debug') or $pDebug = 'true'">
            <div class="message">
                <span class="item">
                    <xsl:text>Dans </xsl:text>
                    <xsl:value-of select="@item" />
                    <xsl:text> : </xsl:text>
                </span>
                <div class="messagesList">
                    <ul>                       
                        <xsl:apply-templates select="../*[@item = current()/@item]" mode='message'/>
                    </ul>
                </div>
            </div>
       </xsl:if>
    </xsl:template>
    
    <xsl:template match="*[local-name()='message']" mode="message">
        <!-- On ne duplique pas un message pour un même item et un même élément -->
        <xsl:if test="not(preceding-sibling::*[. = current() and @item = current()/@item and @model = current()/@model])">
            <li>
                <span title="{@node}" class="model">
                    <xsl:attribute name="class">
                        <xsl:value-of select="@level" />
                    </xsl:attribute>
                    <xsl:value-of select="@model" />
                    <xsl:text> : </xsl:text>
                    <xsl:value-of select="text()" />
                </span>
            </li>
        </xsl:if>
    </xsl:template>
</xsl:stylesheet>