<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:op="utc.fr:ics/opale3"
	xmlns="urn:unit-c.fr:schema:academic:v1" xmlns:bib="urn:unit-c.fr:schema:bibliography:v1"
	xmlns:date="http://xml.apache.org/xalan/java/java.util.Date" extension-element-prefixes="date"
	exclude-result-prefixes="sc sp op bib">

	<xsl:import href="bsco:export.xsl" />

	<!-- Retourne un identifiant unique -->
	<xsl:template name="tId">
		<xsl:variable name="vDate" select="date:new()" />
		<xsl:text>urn:unit-c.fr:</xsl:text>
		<xsl:value-of select="currentModel()" />
		<xsl:value-of select="date:getTime($vDate)" />
	</xsl:template>

	<!-- Crée l'élément id -->
	<xsl:template name="tIdElt">
		<id>
			<xsl:call-template name="tId" />
		</id>
	</xsl:template>

	<!-- Retourne l'URI d'un item référencé ou de l'item courant par défaut sous l'axis 'page' -->
	<xsl:template name="tRefUri">
		<xsl:param name="pCurrentModel" select="false()" />
		<xsl:param name="pAxis">page</xsl:param>
		<xsl:variable name="vPath"
			select="getContent(si($pCurrentModel,currentModel(), gotoSubModel()), $pAxis)" />
		<xsl:text>/</xsl:text>
		<!-- On coupe la chaîne pour arriver à une URI absolu par rapport à l'atelier -->
		<xsl:value-of
			select="substring-after(substring-after(substring-after(substring-after($vPath, '/'), '/'), '/'), '/')" />
		<!--		<xsl:value-of select="$vPath"/>-->
	</xsl:template>

	<!-- Crée l'attribut refUri en utilisant tRefUri -->
	<xsl:template name="tRefUriAttr">
		<xsl:param name="pCurrentModel" select="false()" />
		<xsl:param name="pAxis">page</xsl:param>
		<xsl:attribute name="refUri">
			<xsl:call-template name="tRefUri">
				<xsl:with-param name="pAxis" select="$pAxis" />
				<xsl:with-param name="pCurrentModel" select="$pCurrentModel" />
			</xsl:call-template>
		</xsl:attribute>
	</xsl:template>

	<!-- Patron utilitaire pour signaler l'inexistance d'un élément dans UNIT -->
	<xsl:template name="tNoMatch">
		<xsl:call-template name="tLogError">
			<xsl:with-param name="pMessage">
				<xsl:text>'</xsl:text>
				<xsl:apply-templates select="." mode="label" />
				<xsl:text>' n'a pas de correspondance dans UNIT.</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<!-- Patron de debug pour afficher dans le log les éléments non capturés -->
	<xsl:template match="*">
		<xsl:call-template name="tLogDebug">
			<xsl:with-param name="pMessage">L'élément '<xsl:value-of select="name(.)" />' n'a pas
				été capturé.</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<!-- Extraction de l'extension d'un nom de fichier -->
	<xsl:template name="tExtension">
		<xsl:param name="pFilename" />

		<!-- Appel récursif du patron tant que l'extension contient un point -->
		<xsl:variable name="vExtension" select="substring-after($pFilename, '.')" />
		<xsl:choose>
			<xsl:when test="contains($vExtension,'.')">
				<xsl:call-template name="tExtension">
					<xsl:with-param name="pFilename" select="$vExtension" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$vExtension" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Patron utilitaire pour signaler qu'un format n'est pas supporté (utilisé dans Re.xsl) -->
	<xsl:template name="tNotSupportedFormat">
		<xsl:param name="pFormat" />

		<xsl:call-template name="tLogError">
			<xsl:with-param name="pMessage">
				<xsl:text>Les fichiers '</xsl:text>
				<xsl:value-of select="$vFormat" />
				<xsl:text>' des '</xsl:text>
				<xsl:apply-templates select="$pBinaryElement" mode="label" />
				<xsl:text>' ne sont pas supportés par UNIT.</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	
	<!-- Patron utilitaire pour générer le titre d'un quiz -->
	<xsl:template name="tQuizTitle">
		<title>
			<fullTitle>
				<xsl:apply-templates select="." mode="label" />
			</fullTitle>
		</title>
		<xsl:call-template name="tLogInfo">
			<xsl:with-param name="pMessage">
				<xsl:text>Le titre du quiz a été défini à '</xsl:text>
				<xsl:apply-templates select="." mode="label" />
				<xsl:text>'.</xsl:text>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<!-- Patrons utilitaire pour générer la bibliograhpie -->
	<xsl:template name="tBiblio">
		<!-- Les doublons sont supprimés en post XSL -->
		<bib:bibliography>
			<!-- On passe par un mode particulier pour générer la bibliographie -->
			<xsl:apply-templates mode="biblio" />
		</bib:bibliography>
	</xsl:template>

	<xsl:template match="sp:genRef" />

	<xsl:template match="sp:genRef" mode="biblio">
		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
	</xsl:template>

	<xsl:template match="*" mode="biblio">
		<xsl:apply-templates mode="biblio" />
	</xsl:template>

	<xsl:template match="sc:uLink[@role = 'bib']" mode="biblio">
		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
	</xsl:template>

	<xsl:template match="text()" mode="biblio" />

</xsl:stylesheet>
