<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:op="utc.fr:ics/opale3"
	xmlns="urn:unit-c.fr:schema:academic:v1" xmlns:db="urn:unit-c.fr:schema:docbook:v1"
	exclude-result-prefixes="sc sp op db">

	<xsl:import href="bsco:export.xsl" />
	<xsl:import href="bsco:unit.xsl" />

	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" />

	<xsl:param name="vDialog" />
	<xsl:param name="vAgent" />

	<xsl:template match="op:expUc">
		<ExpositionUc>
			<xsl:call-template name="tIdElt" />
			<xsl:value-of select="getContent(gotoMeta())" disable-output-escaping="yes" />
			<xsl:call-template name="tBiblio" />

			<xsl:call-template name="tDivPolicy" />
		</ExpositionUc>
	</xsl:template>

	<xsl:template name="tDivPolicy">
		<xsl:if test="not(sp:pb | sp:div)">
			<xsl:call-template name="tLogWarning">
				<xsl:with-param name="pMessage">Le cours ou la division ne contient ni balise
					pédagogique ni division.</xsl:with-param>
			</xsl:call-template>
			<information>
				<content>
					<db:text>
						<db:simpara>[Vide]</db:simpara>
					</db:text>
				</content>
			</information>
		</xsl:if>

		<xsl:choose>
			<xsl:when test="sp:div and sp:pb">
				<xsl:choose>
					<xsl:when test="count(ancestor::sp:div) &gt; 1">
						<xsl:apply-templates select="sp:pb" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="tLogWarning">
							<xsl:with-param name="pMessage">UNIT ne permet pas d'avoir des balises
								pédagogiques aux même niveau que des divisions. Les balises
								pédagogiques ont été regroupés dans une partie
							"Introduction".</xsl:with-param>
						</xsl:call-template>

						<xsl:variable name="vDivElement">
							<xsl:choose>
								<xsl:when test="count(ancestor::sp:div) &gt;= 1">subdivision</xsl:when>
								<xsl:otherwise>division</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>

						<xsl:element name="{$vDivElement}">
							<title>
								<fullTitle>Introduction</fullTitle>
							</title>
							<xsl:apply-templates select="sp:pb" />
						</xsl:element>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="sp:pb" />
			</xsl:otherwise>
		</xsl:choose>

		<xsl:choose>
			<xsl:when test="count(ancestor::sp:div) &gt; 1">
				<xsl:if test="sp:div">
					<xsl:call-template name="tLogWarning">
						<xsl:with-param name="pMessage">Le contenu des divisions a été mis à plat
							(le titre est perdu).</xsl:with-param>
					</xsl:call-template>
				</xsl:if>

				<xsl:apply-templates select="sp:div//sp:pb" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="sp:div" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="op:uM" />

	<xsl:template match="sp:pb">
		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
	</xsl:template>

	<xsl:template match="sp:div">
		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
	</xsl:template>

	<!-- Divisions -->
	<xsl:template match="op:expUc/sp:div/op:expUcDiv">
		<division>
			<xsl:value-of select="getContent(gotoMeta())" disable-output-escaping="yes" />
			<xsl:call-template name="tDivPolicy" />
		</division>
	</xsl:template>

	<xsl:template match="op:expUcDiv/sp:div/op:expUcDiv">
		<subdivision>
			<xsl:value-of select="getContent(gotoMeta())" disable-output-escaping="yes" />
			<xsl:call-template name="tDivPolicy" />
		</subdivision>
	</xsl:template>

	<xsl:template match="op:expUcDivM" />

</xsl:stylesheet>
