<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:op="utc.fr:ics/opale3"
	xmlns="urn:unisciel.fr:schema:academic:v1" xmlns:db="urn:unisciel.fr:schema:docbook:v1"
	xmlns:xalan="http://xml.apache.org/xalan" extension-element-prefixes="xalan"
	exclude-result-prefixes="sc sp op db">

	<xsl:import href="bsco:export.xsl" />
	<xsl:import href="bsco:unisciel.xsl" />

	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" />

	<xsl:param name="vDialog" />
	<xsl:param name="vAgent" />

	<!--
		UNIT : description, question+
		Opale : (description | questtion)+
	-->
	<xsl:template match="op:practUc">
		<PracticeUc>
			<xsl:call-template name="tIdElt" />
			<xsl:value-of select="getContent(gotoMeta())" disable-output-escaping="yes" />
			<xsl:call-template name="tBiblio" />
			<!-- On applique par groupe mise en contexte / question en se basant sur une question 'pivot' -->
			<!-- Sélection : les questions non précédées par une mise en contexte ou directement précédées par une et les mises en contexte non suivies par une question -->
			<xsl:apply-templates
				select="sp:quest[(not(preceding-sibling::sp:desc) and not(preceding-sibling::sp:quest)) or preceding-sibling::*[position() = 1 and self::sp:desc]] | sp:desc[not(following-sibling::sp:quest)]"
				mode="problem" />
		</PracticeUc>
	</xsl:template>

	<xsl:template match="op:uM" />

	<xsl:template match="sp:quest" mode="problem">
		<problem>
			<!-- Mises en contexte à regrouper -->
			<xsl:variable name="vDesc"
				select="preceding-sibling::sp:desc[xalan:hasSameNodes(following-sibling::sp:quest[1], current())]" />
			<!-- Questions à regrouper  -->
			<xsl:variable name="vQuest"
				select=". | following-sibling::sp:quest[xalan:hasSameNodes(preceding-sibling::sp:desc[1], $vDesc[last()])]" />

			<!-- Différence avec UNIT : la description est optionelle -->
			<xsl:if test="count($vDesc)">
				<description>
					<xsl:call-template name="tLogWarning">
						<xsl:with-param name="pMessage">Les mises en contexte ont été regroupées
							dans la description.</xsl:with-param>
					</xsl:call-template>

					<xsl:apply-templates select="$vDesc" />
				</description>
			</xsl:if>

			<xsl:apply-templates select="$vQuest" />
		</problem>
	</xsl:template>

	<xsl:template match="sp:desc" mode="problem">
		<xsl:call-template name="tLogWarning">
			<xsl:with-param name="pMessage">La mise en contexte n'est pas suivie par une
			question.</xsl:with-param>
		</xsl:call-template>
		<problem>
			<description>
				<!-- Mises en contexte à regrouper -->
				<!-- Séléction simple car ce template est appliqué uniquement si la mise en contexte n'est pas suivi d'une question -->
				<xsl:apply-templates select=". | following-sibling::sp:desc" />
			</description>
			<question>
				<question>
					<db:text>
						<db:simpara>[Pas de question]</db:simpara>
					</db:text>
				</question>
			</question>
		</problem>
	</xsl:template>

	<xsl:template match="sp:desc">
		<xsl:apply-templates select="op:sTitle" />
		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
	</xsl:template>
	
	<xsl:template match="sp:desc/op:sTitle">
		<title>
			<xsl:value-of select="sc:fullTitle" />
		</title>
	</xsl:template>
	
	<xsl:template match="sp:quest">
		<question>
			<xsl:apply-templates />
		</question>
	</xsl:template>

	<xsl:template match="op:practUcQ">
		<xsl:apply-templates />
	</xsl:template>

	<xsl:template match="op:practUcQ/sp:desc">
		<!--TODO Unit : question/question ? -->
		<question>
			<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
		</question>
	</xsl:template>

	<xsl:template match="op:practUcQ/sp:hint">
		<help>
			<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
		</help>
	</xsl:template>

	<xsl:template match="op:practUcQ/sp:sol">
		<xsl:call-template name="tLogWarning">
			<xsl:with-param name="pMessage">Les balises pédagogiques ne sont pas permises dans les
				solutions d'UNIT. Elles ont été mises à plat.</xsl:with-param>
		</xsl:call-template>
		<solution>
			<xsl:value-of select="getContent(gotoSubModel(), 'flat')" disable-output-escaping="yes"
			 />
		</solution>
	</xsl:template>

</xsl:stylesheet>
