<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:op="utc.fr:ics/opale3"
	xmlns="urn:unit-c.fr:schema:academic:v1" xmlns:db="urn:unit-c.fr:schema:docbook:v1"
	exclude-result-prefixes="sc sp op db">

	<xsl:import href="bsco:export.xsl" />
	<xsl:import href="bsco:unit.xsl" />

	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" />

	<xsl:param name="vDialog" />
	<xsl:param name="vAgent" />

	<xsl:template match="op:res">
		<xsl:apply-templates />
	</xsl:template>

	<xsl:template match="sp:txt">
		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
	</xsl:template>

	<xsl:template match="sp:txtRes">
		<xsl:call-template name="tLogWarning">
			<xsl:with-param name="pMessage">Il n'y a pas de correspondance au texte illustré dans
				UNIT. Il a été mis à plat.</xsl:with-param>
		</xsl:call-template>
		<!-- Les groupes de ressources sont mis l'un en dessous de l'autre en fonction de la position défini par l'auteur -->
		<xsl:choose>
			<xsl:when test="op:txtRes/op:txtResM/sp:pos = 'lft'">
				<xsl:apply-templates select="op:txtRes/sp:res" />
				<xsl:apply-templates select="op:txtRes/sp:txt" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="op:txtRes/sp:txt" />
				<xsl:apply-templates select="op:txtRes/sp:res" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="sp:img | sp:res">
		<xsl:variable name="vExtension">
			<xsl:call-template name="tExtension">
				<xsl:with-param name="pFilename" select="extractFileNameFromPath(@sc:refUri)" />
			</xsl:call-template>
		</xsl:variable>

		<bitmapImage>
			<xsl:choose>
				<!-- Conversion en png des gifs -->
				<xsl:when test="$vExtension = 'gif'">
					<xsl:call-template name="tRefUriAttr">
						<xsl:with-param name="pAxis">pagePng</xsl:with-param>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="tRefUriAttr" />
				</xsl:otherwise>
			</xsl:choose>
		</bitmapImage>
	</xsl:template>

	<xsl:template match="sp:tab">
		<xsl:variable name="vExtension">
			<xsl:call-template name="tExtension">
				<xsl:with-param name="pFilename" select="extractFileNameFromPath(@sc:refUri)" />
			</xsl:call-template>
		</xsl:variable>

		<table>
			<xsl:call-template name="tRefUriAttr" />
		</table>
	</xsl:template>

	<xsl:template match="sp:graph">
		<xsl:variable name="vExtension">
			<xsl:call-template name="tExtension">
				<xsl:with-param name="pFilename" select="extractFileNameFromPath(@sc:refUri)" />
			</xsl:call-template>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="$vExtension = 'swf'">
				<interaction>
					<xsl:call-template name="tRefUriAttr" />
				</interaction>
			</xsl:when>
			<xsl:when test="$vExtension = 'odg'">
				<vectorGraphic>
					<xsl:call-template name="tRefUriAttr" />
				</vectorGraphic>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="tNotSupportedFormat" />
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<xsl:template match="sp:vid">
		<xsl:variable name="vExtension">
			<xsl:call-template name="tExtension">
				<xsl:with-param name="pFilename" select="extractFileNameFromPath(@sc:refUri)" />
			</xsl:call-template>
		</xsl:variable>

		<interaction>
			<xsl:call-template name="tRefUriAttr" />
		</interaction>
	</xsl:template>

	<xsl:template match="sp:int">
		<xsl:variable name="vExtension">
			<xsl:call-template name="tExtension">
				<xsl:with-param name="pFilename" select="extractFileNameFromPath(@sc:refUri)" />
			</xsl:call-template>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="$vExtension = 'pdf'">
				<publishedDocument>
					<xsl:call-template name="tRefUriAttr" />
				</publishedDocument>
			</xsl:when>
			<xsl:otherwise>
				<interaction>
					<xsl:call-template name="tRefUriAttr" />
				</interaction>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="sp:form">
		<xsl:variable name="vExtension">
			<xsl:call-template name="tExtension">
				<xsl:with-param name="pFilename" select="extractFileNameFromPath(@sc:refUri)" />
			</xsl:call-template>
		</xsl:variable>

		<db:text>
			<db:equation>
				<db:mathodf>
					<!-- Conversion en odf des mml et mtex -->
					<xsl:choose>
						<xsl:when test="$vExtension = 'mml' or $vExtension = 'mtex'">
							<xsl:call-template name="tRefUri">
								<xsl:with-param name="pAxis">pageOdf</xsl:with-param>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="tRefUri" />
						</xsl:otherwise>
					</xsl:choose>
				</db:mathodf>
			</db:equation>
		</db:text>
	</xsl:template>

	<xsl:template match="sp:listing">
		<db:text>
			<db:programlisting>
				<xsl:call-template name="tRefUri" />
			</db:programlisting>
		</db:text>
	</xsl:template>

	<xsl:template match="sp:bkquote">
		<db:text>
			<db:blockquote>
				<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
			</db:blockquote>
		</db:text>
	</xsl:template>

	<xsl:template match="sp:simu">
		<xsl:apply-templates select="op:simu/*" />
	</xsl:template>

	<xsl:template match="op:binAltM" />

	<xsl:template match="sp:eweb">
		<interaction>
			<xsl:attribute name="refUri">
				<xsl:call-template name="tRefUri" />
				<xsl:text>.jar</xsl:text>
			</xsl:attribute>
		</interaction>
	</xsl:template>

	<xsl:template match="sp:xmllab">
		<interaction>
			<xsl:call-template name="tRefUriAttr" />
		</interaction>
	</xsl:template>

	<xsl:template match="sp:vidInd">
		<xsl:call-template name="tNotSupportedFormat" />
	</xsl:template>

</xsl:stylesheet>
