<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:ut="urn:unit-c.fr:schema:academic:v1" xmlns="urn:unisciel.fr:schema:academic:v1"
    xmlns:dbut="urn:unit-c.fr:schema:docbook:v1" xmlns:db="urn:unisciel.fr:schema:docbook:v1"
    xmlns:bibut="urn:unit-c.fr:schema:bibliography:v1"
    xmlns:bib="urn:unisciel.fr:schema:bibliography:v1" xmlns:lom="http://ltsc.ieee.org/xsd/LOM"
    xmlns:lomfr="http://www.lom-fr.fr/xsd/LOMFR" exclude-result-prefixes="ut dbut db bibut bib">

    <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"
        cdata-section-elements="lom:entity" />

    <xsl:strip-space elements="*" />

    <xsl:template match="node() | @*">
        <xsl:copy>
            <xsl:apply-templates select="node() | @*" />
        </xsl:copy>
    </xsl:template>

    <!-- Conversion des éléments et identifiant UNIT en Unisciel -->
    <xsl:template match="ut:*">
        <xsl:element name="{local-name()}">
            <xsl:apply-templates select="node() | @*" />
        </xsl:element>
    </xsl:template>

    <xsl:template match="ut:id">
        <id>
            <xsl:text>urn:unisciel.fr:</xsl:text>
            <xsl:value-of select="substring-after(., 'urn:unit-c.fr:')" />
        </id>
    </xsl:template>

    <!-- Bien qu'étant dans le bon namespace, recopie "manuel" pour que le namespace UNIT n'apparaisse pas -->
    <xsl:template match="lom:*">
        <xsl:element name="lom:{local-name()}">
            <xsl:apply-templates select="node() | @*" />
        </xsl:element>
    </xsl:template>

    <xsl:template match="lomfr:*">
        <xsl:element name="lomfr:{local-name()}">
            <xsl:apply-templates select="node() | @*" />
        </xsl:element>
    </xsl:template>


    <xsl:template match="lom:identifier/lom:entry">
        <lom:entry>
            <xsl:text>urn:unisciel.fr:</xsl:text>
            <xsl:value-of select="substring-after(., 'urn:unit-c.fr:')" />
        </lom:entry>
    </xsl:template>

    <xsl:template match="dbut:*">
        <xsl:element name="db:{local-name()}">
            <xsl:apply-templates select="node() | @*" />
        </xsl:element>
    </xsl:template>

    <xsl:template match="bibut:*">
        <xsl:element name="bib:{local-name()}">
            <xsl:apply-templates select="node() | @*" />
        </xsl:element>
    </xsl:template>

    <!-- Suppression des doublons dans la bibliographie -->
    <xsl:template match="bibut:bibliography[bibut:biblioentry]">
        <bib:bibliography>
            <xsl:apply-templates
                select="bibut:biblioentry[not(preceding-sibling::bibut:biblioentry/@id = @id)]" />
        </bib:bibliography>
    </xsl:template>

    <!-- Suppression de la bibliographie si vide -->
    <xsl:template match="bibut:bibliography" />
</xsl:stylesheet>
