<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:op="utc.fr:ics/opale3"
    xmlns="urn:unit-c.fr:schema:academic:v1" xmlns:db="urn:unit-c.fr:schema:docbook:v1"
    xmlns:java="http://xml.apache.org/xslt/java" exclude-result-prefixes="sc sp op java">

    <xsl:import href="bsco:export.xsl" />
    <xsl:import href="bsco:unit.xsl" />

    <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" />

    <xsl:param name="vDialog" />
    <xsl:param name="vAgent" />

    <xsl:template match="sc:inlineStyle[@role='quote']">
        <db:quote>
            <xsl:apply-templates />
        </db:quote>
    </xsl:template>

    <xsl:template match="sc:inlineStyle[@role='emp']">
        <db:emphasis>
            <xsl:apply-templates />
        </db:emphasis>
    </xsl:template>

    <xsl:template match="sc:inlineStyle[@role='spec']">
        <db:phrase>
            <xsl:apply-templates />
        </db:phrase>
    </xsl:template>

    <xsl:template match="sc:inlineStyle[@role='code']">
        <db:command>
            <xsl:value-of select="." />
        </db:command>
    </xsl:template>

    <xsl:template match="sc:uLink[not(@role)]">
        <db:ulink url="{@url}">
            <xsl:value-of select="." />
        </db:ulink>
    </xsl:template>

    <xsl:template match="sc:uLink[not(@role) and starts-with(@url, 'mailto:')]" priority="1">
        <db:email>
            <xsl:apply-templates />
        </db:email>
    </xsl:template>

    <xsl:template match="sc:uLink[@role = 'acr']">
        <xsl:if test="contains(., ' ')">
            <xsl:call-template name="tLogError">
                <xsl:with-param name="pMessage">L'abréviation contient un espace. Ceci est
                    incompatible avec le type des acronymes d'UNIT.</xsl:with-param>
            </xsl:call-template>
        </xsl:if>
        <xsl:call-template name="tLogError">
            <xsl:with-param name="pMessage">La signification de l'acronyme est
            perdue.</xsl:with-param>
        </xsl:call-template>

        <db:acronym>
            <xsl:apply-templates />
        </db:acronym>
    </xsl:template>

    <xsl:template match="sc:uLink[@role = 'glos']">
        <xsl:call-template name="tNoMatch" />

        <!-- TODO Unit pas de glossaire ? -->
        <xsl:apply-templates />
    </xsl:template>

    <xsl:template match="sc:uLink[@role = 'bib']">
        <!-- TODO Unit La recommandation indique d'utiliser le mécanisme xref mais propose l'attribut linkend (qui pointe vers un id dans le schéma) -->
        <!-- Si xref problème car auteur et année non obligatoire -->
        <xsl:apply-templates />
        <db:biblioref linkend="{gotoSubModel()}" />
    </xsl:template>

    <xsl:template match="sc:uLink[@role = 'ref']">
        <xsl:call-template name="tNoMatch" />

        <xsl:apply-templates />
    </xsl:template>

    <xsl:template match="sc:uLink[@role = 'docLnk']">
        <xsl:call-template name="tNoMatch" />

        <xsl:apply-templates />
    </xsl:template>

    <xsl:template match="sc:uLink[@role = 'resLnk']">
        <xsl:call-template name="tNoMatch" />

        <xsl:apply-templates />
    </xsl:template>

    <xsl:template match="sc:textLeaf[@role = 'exp']">
        <xsl:call-template name="tNoMatch" />
        <!-- TODO pas superscript dans le db d'UNIT -->
        <xsl:apply-templates />
    </xsl:template>

    <xsl:template match="sc:textLeaf[@role = 'ind']">
        <xsl:call-template name="tNoMatch" />
        <!-- TODO pas subscript dans le db d'UNIT  -->
        <xsl:apply-templates />
    </xsl:template>

    <xsl:template match="sc:textLeaf[@role = 'mathtex']">
        <db:inlineequation>
            <db:mathodf>
                <xsl:variable name="vBaseUri" select="resultatAgent('//', concat('resUri:src=src:', java:hGetUri(srcFileAgent()), '?transform=latex2mathml&amp;omitXmlDeclaration=yes&amp;content=', java:java.net.URLEncoder.encode(java:replaceAll(string(.), '&amp;amp;', '%26'), 'UTF-8'), '&amp;fileExt=.odf&amp;transform=mathml2mathmlOO&amp;transform=mml2odf', '&amp;mutabledst=', resultatAgent('/@@/outTmpResources'), '/', java:hGetUri(srcFileAgent()),'.odf'))" />
                <xsl:value-of select="concat('/',substring-after(substring-after(substring-after(substring-after($vBaseUri,'/'),'/'),'/'),'/'))" />
            </db:mathodf>
        </db:inlineequation>
    </xsl:template>

    <xsl:template match="sc:inlineImg[@role = 'form']">
        <xsl:variable name="vExtension">
            <xsl:call-template name="tExtension">
                <xsl:with-param name="pFilename" select="extractFileNameFromPath(@sc:refUri)" />
            </xsl:call-template>
        </xsl:variable>

        <db:inlineequation>
            <db:mathodf>
                <xsl:choose>
                    <xsl:when test="$vExtension = 'mml' or $vExtension = 'mtex'">
                        <xsl:call-template name="tRefUri">
                            <xsl:with-param name="pAxis">pageOdf</xsl:with-param>
                        </xsl:call-template>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:call-template name="tRefUri" />
                    </xsl:otherwise>
                </xsl:choose>
            </db:mathodf>
        </db:inlineequation>
    </xsl:template>

    <xsl:template match="sc:inlineImg[@role = 'ico']">
        <xsl:variable name="vExtension">
            <xsl:call-template name="tExtension">
                <xsl:with-param name="pFilename" select="extractFileNameFromPath(@sc:refUri)" />
            </xsl:call-template>
        </xsl:variable>

        <db:guiicon>
            <xsl:choose>
                <xsl:when test="$vExtension = 'gif'">
                    <xsl:call-template name="tRefUriAttr">
                        <xsl:with-param name="pAxis">pagePng</xsl:with-param>
                    </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:call-template name="tRefUriAttr" />
                </xsl:otherwise>
            </xsl:choose>
        </db:guiicon>
        <!-- TODO guiico : quel sont les types de fichier supportés ? <db:inlinegraphic> plus adapté ? ?-->
    </xsl:template>

</xsl:stylesheet>
