<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:op="utc.fr:ics/opale3" xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:java="http://xml.apache.org/xalan/java"
	extension-element-prefixes="java">

	<xsl:param name="vDialog" />
	<xsl:param name="vAgent" />
	
	<!-- Ensemble de patron pour gérer les messages de log -->
	<xsl:template name="tLog">
		<xsl:param name="pMessage" />
		<xsl:param name="pLevel" />
		<xsl:param name="pNode" select="." />

		<xsl:variable name="vPath">
			<xsl:for-each select="$pNode/ancestor-or-self::*">
				<xsl:variable name="vPreceding"
					select="preceding-sibling::*[name(.) = name(current())]" />
				<xsl:value-of select="name(.)" />
				<xsl:if test="$vPreceding or following-sibling::*[name(.) = name(current())]">
					<xsl:text>[</xsl:text>
					<xsl:value-of select="count($vPreceding) + 1" />
					<xsl:text>]</xsl:text>
				</xsl:if>
				<xsl:if test="position() != last()">/</xsl:if>
			</xsl:for-each>
		</xsl:variable>

		<xsl:variable name="vModel">
			<xsl:apply-templates select="$pNode/ancestor-or-self::op:*[1]" mode="label" />
		</xsl:variable>

		<xsl:variable name="vSrcFile"
			select="substring-after(substring-after(java:hGetUri(srcFileAgent('//')),'/'),'/')" />

		<xsl:variable name="vMessageXml"
			select="concat('&lt;message level=&quot;', $pLevel, '&quot; item=&quot;',  $vSrcFile, '&quot; node=&quot;', $vPath, '&quot; model=&quot;',  $vModel,'&quot;&gt;', normalize-space($pMessage), '&lt;/message&gt;')" />

		<xsl:value-of select="execute(setEntryBuffer('fLogBuffer', $vMessageXml))" />
	</xsl:template>

	<xsl:template name="tLogDebug">
		<xsl:param name="pMessage" />
		<xsl:call-template name="tLog">
			<xsl:with-param name="pMessage" select="$pMessage" />
			<xsl:with-param name="pLevel">debug</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="tLogInfo">
		<xsl:param name="pMessage" />
		<xsl:call-template name="tLog">
			<xsl:with-param name="pMessage" select="$pMessage" />
			<xsl:with-param name="pLevel">info</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="tLogWarning">
		<xsl:param name="pMessage" />
		<xsl:call-template name="tLog">
			<xsl:with-param name="pMessage" select="$pMessage" />
			<xsl:with-param name="pLevel">warning</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="tLogError">
		<xsl:param name="pMessage" />
		<xsl:call-template name="tLog">
			<xsl:with-param name="pMessage" select="$pMessage" />
			<xsl:with-param name="pLevel">error</xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="tLogFatal">
		<xsl:param name="pMessage" />
		<xsl:call-template name="tLog">
			<xsl:with-param name="pMessage" select="$pMessage" />
			<xsl:with-param name="pLevel">fatal</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

</xsl:stylesheet>
