<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:op="utc.fr:ics/opale3"
	xmlns:dc="urn:unit-c.fr:schema:dublincore:v1" exclude-result-prefixes="sc sp op">

	<xsl:import href="bsco:export.xsl" />
	<xsl:import href="bsco:unit.xsl" />

	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" />

	<xsl:param name="vDialog" />
	<xsl:param name="vAgent" />

	<xsl:template match="op:info">
		<dc:head>
			<xsl:choose>
				<xsl:when test="not(sp:dc/op:dc/sp:auth)">
					<xsl:variable name="vAuthor"
						select="normalize-space(getContent(rootModel(), 'auth'))" />
	
					<xsl:choose>
						<xsl:when test="string-length($vAuthor)">
							<xsl:value-of select="$vAuthor" disable-output-escaping="yes" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="tLogFatal">
								<xsl:with-param name="pMessage">UNIT requiert la définition d'au moins
									un auteur sur les documents externes. Veuillez renseigner cette
									information sur le module.</xsl:with-param>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="sp:dc/op:dc/sp:auth" />
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates select="sp:dc/op:dc/sp:cont" />
			<xsl:apply-templates select="sp:dc/op:dc/sp:publisher" />
			<xsl:apply-templates select="sp:dc/op:dc/sp:desc" />
			<xsl:apply-templates select="sp:keywds/op:keywds/sp:keywd" />
			<xsl:apply-templates select="sp:dc/op:dc/sp:lang" />
			<xsl:apply-templates select="sp:dc/op:dc/sp:cover/sp:spatial" />
			<xsl:apply-templates select="sp:cc" />
			<xsl:apply-templates select="sp:dc/op:dc/sp:level" />

			<!-- Application pour le log -->
			<xsl:apply-templates select="sp:cpyrgt | sp:dc/op:dc/sp:objs | sp:dc/op:dc/sp:date" />
		</dc:head>
	</xsl:template>

	<xsl:template match="op:dc/sp:auth">
		<!--
			TODO Expression régulière très étrange : '([^ ])* ([^ ])+'
			Le prénom n'est pas obligatoire mais l'espace oui...
		-->
		<dc:creator>
			<xsl:value-of select="." />
		</dc:creator>
	</xsl:template>

	<xsl:template match="op:dc/sp:cont">
		<dc:contributor>
			<xsl:value-of select="." />
		</dc:contributor>
	</xsl:template>

	<xsl:template match="op:dc/sp:publisher">
		<dc:publisher>
			<xsl:value-of select="." />
		</dc:publisher>
	</xsl:template>

	<xsl:template match="op:dc/sp:desc">
		<xsl:call-template name="tLogWarning">
			<xsl:with-param name="pMessage">La description a été mise à plat.</xsl:with-param>
		</xsl:call-template>

		<dc:description>
			<xsl:value-of select="normalize-space(.)" />
		</dc:description>
	</xsl:template>

	<xsl:template match="op:keywds/sp:keywd">
		<dc:subject>
			<xsl:value-of select="." />
		</dc:subject>
	</xsl:template>

	<xsl:template match="op:dc/sp:lang">
		<dc:language>
			<xsl:choose>
				<xsl:when test=". = 'FR'">fr</xsl:when>
				<xsl:when test=". = 'EN'">en</xsl:when>
			</xsl:choose>
		</dc:language>
	</xsl:template>

	<xsl:template match="op:dc/sp:lang[. = 'OT']">
		<xsl:call-template name="tLogError">
			<xsl:with-param name="pMessage">La langue définie à 'Autre' a été
			perdu.</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="op:dc/sp:cover/sp:spatial">
		<dc:spatial>
			<xsl:choose>
				<xsl:when test=". = 'FR'">fr</xsl:when>
				<xsl:when test=". = 'EN'">en</xsl:when>
			</xsl:choose>
		</dc:spatial>
	</xsl:template>

	<xsl:template match="op:dc/sp:cover/sp:spatial[. = 'OT']">
		<xsl:call-template name="tLogError">
			<xsl:with-param name="pMessage">La couverture spatiale a été définie à 'Autre' a été
			perdu.</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="op:dc/sp:level">
		<dc:educationLevel>
			<xsl:value-of select="." />
		</dc:educationLevel>
	</xsl:template>

	<xsl:template match="sp:cc">
		<dc:rights>
			<xsl:choose>
				<xsl:when test=". = 'by-nd'">
					<xsl:call-template name="tLogWarning">
						<xsl:with-param name="pMessage">La licence 'by-nd' a été converti en
							'by-nc-nd'.</xsl:with-param>
					</xsl:call-template>
					<xsl:text>http://creativecommons.org/licenses/by-nc-nd/2.0/</xsl:text>
				</xsl:when>
				<xsl:when test=". = 'by-sa'">
					<xsl:call-template name="tLogWarning">
						<xsl:with-param name="pMessage">La licence 'by-sa' a été converti en
							'by-nc-sa'.</xsl:with-param>

					</xsl:call-template>
					<xsl:text>http://creativecommons.org/licenses/by-nc-sa/2.0/</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>http://creativecommons.org/licenses/</xsl:text>
					<xsl:value-of select="." />
					<xsl:if test="not(. = 'publicdomain')">
						<xsl:text>/2.0</xsl:text>
					</xsl:if>
					<xsl:text>/</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</dc:rights>
	</xsl:template>

	<xsl:template match="sp:cpyrgt">
		<xsl:call-template name="tNoMatch" />
	</xsl:template>

	<xsl:template match="op:dc/sp:objs">
		<xsl:call-template name="tNoMatch" />
	</xsl:template>

	<xsl:template match="op:dc/sp:date">
		<xsl:call-template name="tNoMatch" />
	</xsl:template>

</xsl:stylesheet>


