<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:op="utc.fr:ics/opale3"
	xmlns="urn:unit-c.fr:schema:academic:v1" exclude-result-prefixes="sc sp op">

	<xsl:import href="bsco:export.xsl" />
	<xsl:import href="bsco:unit.xsl" />

	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" />

	<xsl:param name="vDialog" />
	<xsl:param name="vAgent" />

	<xsl:template match="op:ue">
		<AcademicUe>
			<xsl:call-template name="tIdElt" />
			<xsl:value-of select="getContent(gotoMeta())" disable-output-escaping="yes" />
			<xsl:call-template name="tBiblio" />

			<xsl:apply-templates />
		</AcademicUe>
	</xsl:template>

	<xsl:template match="op:ueM" />

	<xsl:template match="sp:obj" />

	<xsl:template match="sp:obj[not(following-sibling::sp:intro)]">
		<introduction>
			<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
		</introduction>
	</xsl:template>

	<xsl:template match="sp:intro">
		<xsl:variable name="vObj" select="preceding-sibling::sp:obj" />
		<introduction>
			<xsl:if test="$vObj">
				<xsl:call-template name="tLogInfo">
					<xsl:with-param name="pMessage">Les objectifs du module ont été intégrés dans
						l'introduction.</xsl:with-param>
				</xsl:call-template>
				<xsl:value-of select="getContent(gotoSubModel($vObj))" disable-output-escaping="yes"
				 />
			</xsl:if>

			<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
		</introduction>
	</xsl:template>

	<xsl:template match="sp:courseUa">
		<CourseUa>
			<xsl:call-template name="tRefUri" />
		</CourseUa>
	</xsl:template>

	<xsl:template match="sp:assmntUa">
		<AutoevaluationUa>
			<xsl:call-template name="tRefUri" />
		</AutoevaluationUa>
	</xsl:template>

	<xsl:template match="sp:div">
		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
	</xsl:template>

	<xsl:template match="sp:courseUc">
		<ExpositionUc>
			<xsl:call-template name="tRefUri" />
		</ExpositionUc>
	</xsl:template>

	<xsl:template match="sp:practUc">
		<PracticeUc>
			<xsl:call-template name="tRefUri" />
		</PracticeUc>
	</xsl:template>

	<xsl:template match="sp:trainUc">
		<xsl:call-template name="tLogInfo">
			<xsl:with-param name="pMessage">L'exercice intéractif a été transformé en une Activité
				d'évaluation.</xsl:with-param>
		</xsl:call-template>
		<AutoevaluationUa>
			<xsl:call-template name="tRefUri" />
		</AutoevaluationUa>
	</xsl:template>

	<xsl:template match="sp:conclu">
		<conclusion>
			<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
		</conclusion>
	</xsl:template>

	<!-- Divisions -->
	<xsl:template match="op:ue/sp:div/op:ueDiv">
		<division>
			<xsl:value-of select="getContent(gotoMeta())" disable-output-escaping="yes" />
			<xsl:apply-templates />
		</division>
	</xsl:template>

	<xsl:template match="op:ueDiv/sp:div/op:ueDiv">
		<subdivision>
			<xsl:value-of select="getContent(gotoMeta())" disable-output-escaping="yes" />
			<xsl:apply-templates />
		</subdivision>
	</xsl:template>

	<xsl:template match="op:ueDiv/sp:div/op:ueDiv//op:ueDiv">
		<xsl:call-template name="tLogError">
			<xsl:with-param name="pMessage">La profondeur des divisions étant limitée dans UNIT, la
				divison du module a été mise à plat (le titre, l'introduction et la conclusion sont
				perdus).</xsl:with-param>
		</xsl:call-template>
		<xsl:apply-templates select="*[not(self::op:ueDivM | self::sp:intro | self::sp:conclu)]" />
	</xsl:template>

	<xsl:template match="op:ueDivM" />

</xsl:stylesheet>
